@@ -7,11 +7,12 @@ import os
 
 try:
     from pytest_astropy_header.display import PYTEST_HEADER_MODULES, TESTED_VERSIONS
+
     ASTROPY_HEADER = True
 except ImportError:
     ASTROPY_HEADER = False
 
-os.environ['MPLBACKEND'] = 'Agg'
+os.environ["MPLBACKEND"] = "Agg"
 
 
 def pytest_configure(config):
@@ -20,13 +21,13 @@ def pytest_configure(config):
 
         config.option.astropy_header = True
 
-        PYTEST_HEADER_MODULES.pop('Pandas', None)
-        PYTEST_HEADER_MODULES.pop('h5py', None)
-        PYTEST_HEADER_MODULES.pop('Matplotlib', None)
-        PYTEST_HEADER_MODULES['Astropy'] = 'astropy'
-        PYTEST_HEADER_MODULES['astropy-healpix'] = 'astropy_healpix'
-        PYTEST_HEADER_MODULES['Cython'] = 'cython'
+        PYTEST_HEADER_MODULES.pop("Pandas", None)
+        PYTEST_HEADER_MODULES.pop("h5py", None)
+        PYTEST_HEADER_MODULES.pop("Matplotlib", None)
+        PYTEST_HEADER_MODULES["Astropy"] = "astropy"
+        PYTEST_HEADER_MODULES["astropy-healpix"] = "astropy_healpix"
+        PYTEST_HEADER_MODULES["Cython"] = "cython"
 
-        from . import __version__
-        packagename = os.path.basename(os.path.dirname(__file__))
-        TESTED_VERSIONS[packagename] = __version__
+        from reproject import __version__
+
+        TESTED_VERSIONS["reproject"] = __version__
