@@ -4,11 +4,12 @@ from ..utils import parse_input_data, parse_output_projection
 from ..wcs_utils import has_celestial
 from .core import _reproject_celestial
 
-__all__ = ['reproject_exact']
+__all__ = ["reproject_exact"]
 
 
-def reproject_exact(input_data, output_projection, shape_out=None, hdu_in=0,
-                    parallel=False, return_footprint=True):
+def reproject_exact(
+    input_data, output_projection, shape_out=None, hdu_in=0, parallel=False, return_footprint=True
+):
     """
     Reproject data to a new projection using flux-conserving spherical
     polygon intersection (this is the slowest algorithm).
@@ -29,6 +30,12 @@ def reproject_exact(input_data, output_projection, shape_out=None, hdu_in=0,
             * An `~astropy.nddata.NDData` object from which the ``.data`` and
               ``.wcs`` attributes will be used as the input data.
 
+        If the data array contains more dimensions than are described by the
+        input header or WCS, the extra dimensions (assumed to be the first
+        dimensions) are taken to represent multiple images with the same
+        coordinate information. The coordinate transformation will be computed
+        once and then each image will be reprojected, offering a speedup over
+        reprojecting each image individually.
     output_projection : `~astropy.wcs.WCS` or `~astropy.io.fits.Header`
         The output projection, which can be either a `~astropy.wcs.WCS`
         or a `~astropy.io.fits.Header` instance.
@@ -58,11 +65,21 @@ def reproject_exact(input_data, output_projection, shape_out=None, hdu_in=0,
     """
 
     array_in, wcs_in = parse_input_data(input_data, hdu_in=hdu_in)
-    wcs_out, shape_out = parse_output_projection(output_projection, shape_out=shape_out)
+    wcs_out, shape_out = parse_output_projection(
+        output_projection, shape_in=array_in.shape, shape_out=shape_out
+    )
 
     if has_celestial(wcs_in) and wcs_in.pixel_n_dim == 2 and wcs_in.world_n_dim == 2:
-        return _reproject_celestial(array_in, wcs_in, wcs_out, shape_out=shape_out,
-                                    parallel=parallel, return_footprint=return_footprint)
+        return _reproject_celestial(
+            array_in,
+            wcs_in,
+            wcs_out,
+            shape_out=shape_out,
+            parallel=parallel,
+            return_footprint=return_footprint,
+        )
     else:
-        raise NotImplementedError("Currently only data with a 2-d celestial "
-                                  "WCS can be reprojected using flux-conserving algorithm")
+        raise NotImplementedError(
+            "Currently only data with a 2-d celestial "
+            "WCS can be reprojected using flux-conserving algorithm"
+        )
