@@ -1,6 +1,7 @@
 import os
-from distutils.core import Extension
+
 import numpy as np
+from setuptools import Extension
 
 REPROJECT_ROOT = os.path.relpath(os.path.dirname(__file__))
 
@@ -20,8 +21,8 @@ def get_extensions():
     # Note that to set the DEBUG variable in the overlapArea.c code, which
     # results in debugging information being printed out, you can set
     # DEBUG_OVERLAP_AREA=1 at build-time.
-    if int(os.environ.get('DEBUG_OVERLAP_AREA', 0)):
-        define_macros = [('DEBUG_OVERLAP_AREA', 1)]
+    if int(os.environ.get("DEBUG_OVERLAP_AREA", 0)):
+        define_macros = [("DEBUG_OVERLAP_AREA", 1)]
     else:
         define_macros = None
 
@@ -31,7 +32,8 @@ def get_extensions():
         include_dirs=include_dirs,
         libraries=libraries,
         language="c",
-        extra_compile_args=['-O2'],
-        define_macros=define_macros)
+        extra_compile_args=["-O2"],
+        define_macros=define_macros,
+    )
 
     return [extension]
